@@ -44,7 +44,9 @@ pub fn parse(attr: TokenStream, item: TokenStream) -> TokenStream {
                 #name_str
             }
 
-            fn wrap(sandbox: &mut Sandbox, args: &[Value]) -> Result<ReturnValue> {
+            fn wrap(sandbox: &mut Sandbox, args: &[Value]) -> Result<Option<Value>> {
+                log::debug!("call {}::{}", #module, #name_str);
+
                 if args.len() != #arg_len {
                     return Err(Error::WrongArugmentLength);
                 }
